# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['TtlScheduleArgs', 'TtlSchedule']

@pulumi.input_type
class TtlScheduleArgs:
    def __init__(__self__, *,
                 organization: pulumi.Input[str],
                 project: pulumi.Input[str],
                 stack: pulumi.Input[str],
                 timestamp: pulumi.Input[str],
                 delete_after_destroy: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a TtlSchedule resource.
        :param pulumi.Input[str] organization: Organization name.
        :param pulumi.Input[str] project: Project name.
        :param pulumi.Input[str] stack: Stack name.
        :param pulumi.Input[str] timestamp: The time at which the schedule should run, in ISO 8601 format. Eg: 2020-01-01T00:00:00Z.
        :param pulumi.Input[bool] delete_after_destroy: True if the stack and all associated history and settings should be deleted.
        """
        pulumi.set(__self__, "organization", organization)
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "stack", stack)
        pulumi.set(__self__, "timestamp", timestamp)
        if delete_after_destroy is None:
            delete_after_destroy = False
        if delete_after_destroy is not None:
            pulumi.set(__self__, "delete_after_destroy", delete_after_destroy)

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Input[str]:
        """
        Organization name.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        Project name.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def stack(self) -> pulumi.Input[str]:
        """
        Stack name.
        """
        return pulumi.get(self, "stack")

    @stack.setter
    def stack(self, value: pulumi.Input[str]):
        pulumi.set(self, "stack", value)

    @property
    @pulumi.getter
    def timestamp(self) -> pulumi.Input[str]:
        """
        The time at which the schedule should run, in ISO 8601 format. Eg: 2020-01-01T00:00:00Z.
        """
        return pulumi.get(self, "timestamp")

    @timestamp.setter
    def timestamp(self, value: pulumi.Input[str]):
        pulumi.set(self, "timestamp", value)

    @property
    @pulumi.getter(name="deleteAfterDestroy")
    def delete_after_destroy(self) -> Optional[pulumi.Input[bool]]:
        """
        True if the stack and all associated history and settings should be deleted.
        """
        return pulumi.get(self, "delete_after_destroy")

    @delete_after_destroy.setter
    def delete_after_destroy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "delete_after_destroy", value)


class TtlSchedule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 delete_after_destroy: Optional[pulumi.Input[bool]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 stack: Optional[pulumi.Input[str]] = None,
                 timestamp: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        A scheduled stack destory run.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] delete_after_destroy: True if the stack and all associated history and settings should be deleted.
        :param pulumi.Input[str] organization: Organization name.
        :param pulumi.Input[str] project: Project name.
        :param pulumi.Input[str] stack: Stack name.
        :param pulumi.Input[str] timestamp: The time at which the schedule should run, in ISO 8601 format. Eg: 2020-01-01T00:00:00Z.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TtlScheduleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        A scheduled stack destory run.

        :param str resource_name: The name of the resource.
        :param TtlScheduleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TtlScheduleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 delete_after_destroy: Optional[pulumi.Input[bool]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 stack: Optional[pulumi.Input[str]] = None,
                 timestamp: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TtlScheduleArgs.__new__(TtlScheduleArgs)

            if delete_after_destroy is None:
                delete_after_destroy = False
            __props__.__dict__["delete_after_destroy"] = delete_after_destroy
            if organization is None and not opts.urn:
                raise TypeError("Missing required property 'organization'")
            __props__.__dict__["organization"] = organization
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if stack is None and not opts.urn:
                raise TypeError("Missing required property 'stack'")
            __props__.__dict__["stack"] = stack
            if timestamp is None and not opts.urn:
                raise TypeError("Missing required property 'timestamp'")
            __props__.__dict__["timestamp"] = timestamp
            __props__.__dict__["schedule_id"] = None
        super(TtlSchedule, __self__).__init__(
            'pulumiservice:index:TtlSchedule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'TtlSchedule':
        """
        Get an existing TtlSchedule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = TtlScheduleArgs.__new__(TtlScheduleArgs)

        __props__.__dict__["delete_after_destroy"] = None
        __props__.__dict__["organization"] = None
        __props__.__dict__["project"] = None
        __props__.__dict__["schedule_id"] = None
        __props__.__dict__["stack"] = None
        __props__.__dict__["timestamp"] = None
        return TtlSchedule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="deleteAfterDestroy")
    def delete_after_destroy(self) -> pulumi.Output[Optional[bool]]:
        """
        True if the stack and all associated history and settings should be deleted.
        """
        return pulumi.get(self, "delete_after_destroy")

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Output[str]:
        """
        Organization name.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        Project name.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="scheduleId")
    def schedule_id(self) -> pulumi.Output[str]:
        """
        Schedule ID of the created schedule, assigned by Pulumi Cloud.
        """
        return pulumi.get(self, "schedule_id")

    @property
    @pulumi.getter
    def stack(self) -> pulumi.Output[str]:
        """
        Stack name.
        """
        return pulumi.get(self, "stack")

    @property
    @pulumi.getter
    def timestamp(self) -> pulumi.Output[str]:
        """
        The time at which the schedule should run, in ISO 8601 format. Eg: 2020-01-01T00:00:00Z.
        """
        return pulumi.get(self, "timestamp")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'EnvironmentPermission',
    'PulumiOperation',
    'TeamStackPermissionScope',
    'WebhookFilters',
    'WebhookFormat',
]


class EnvironmentPermission(str, Enum):
    NONE = "none"
    """
    No permissions.
    """
    READ = "read"
    """
    Permission to read environment definition only.
    """
    OPEN = "open"
    """
    Permission to open and read the environment.
    """
    WRITE = "write"
    """
    Permission to open, read and update the environment.
    """
    ADMIN = "admin"
    """
    Permission for all operations on the environment.
    """


class PulumiOperation(str, Enum):
    UPDATE = "update"
    """
    Analogous to `pulumi up` command.
    """
    PREVIEW = "preview"
    """
    Analogous to `pulumi preview` command.
    """
    REFRESH = "refresh"
    """
    Analogous to `pulumi refresh` command.
    """
    DESTROY = "destroy"
    """
    Analogous to `pulumi destroy` command.
    """


class TeamStackPermissionScope(float, Enum):
    READ = 101
    """
    Grants read permissions to stack.
    """
    EDIT = 102
    """
    Grants edit permissions to stack.
    """
    ADMIN = 103
    """
    Grants admin permissions to stack.
    """


class WebhookFilters(str, Enum):
    STACK_CREATED = "stack_created"
    """
    Trigger a webhook when a stack is created. Only valid for org webhooks.
    """
    STACK_DELETED = "stack_deleted"
    """
    Trigger a webhook when a stack is deleted. Only valid for org webhooks.
    """
    UPDATE_SUCCEEDED = "update_succeeded"
    """
    Trigger a webhook when a stack update succeeds.
    """
    UPDATE_FAILED = "update_failed"
    """
    Trigger a webhook when a stack update fails.
    """
    PREVIEW_SUCCEEDED = "preview_succeeded"
    """
    Trigger a webhook when a stack preview succeeds.
    """
    PREVIEW_FAILED = "preview_failed"
    """
    Trigger a webhook when a stack preview fails.
    """
    DESTROY_SUCCEEDED = "destroy_succeeded"
    """
    Trigger a webhook when a stack destroy succeeds.
    """
    DESTROY_FAILED = "destroy_failed"
    """
    Trigger a webhook when a stack destroy fails.
    """
    REFRESH_SUCCEEDED = "refresh_succeeded"
    """
    Trigger a webhook when a stack refresh succeeds.
    """
    REFRESH_FAILED = "refresh_failed"
    """
    Trigger a webhook when a stack refresh fails.
    """
    DEPLOYMENT_QUEUED = "deployment_queued"
    """
    Trigger a webhook when a deployment is queued.
    """
    DEPLOYMENT_STARTED = "deployment_started"
    """
    Trigger a webhook when a deployment starts running.
    """
    DEPLOYMENT_SUCCEEDED = "deployment_succeeded"
    """
    Trigger a webhook when a deployment succeeds.
    """
    DEPLOYMENT_FAILED = "deployment_failed"
    """
    Trigger a webhook when a deployment fails.
    """
    DRIFT_DETECTED = "drift_detected"
    """
    Trigger a webhook when drift is detected.
    """
    DRIFT_DETECTION_SUCCEEDED = "drift_detection_succeeded"
    """
    Trigger a webhook when a drift detection run succeeds, regardless of whether drift is detected.
    """
    DRIFT_DETECTION_FAILED = "drift_detection_failed"
    """
    Trigger a webhook when a drift detection run fails.
    """
    DRIFT_REMEDIATION_SUCCEEDED = "drift_remediation_succeeded"
    """
    Trigger a webhook when a drift remediation run succeeds.
    """
    DRIFT_REMEDIATION_FAILED = "drift_remediation_failed"
    """
    Trigger a webhook when a drift remediation run fails.
    """


class WebhookFormat(str, Enum):
    RAW = "raw"
    """
    The default webhook format.
    """
    SLACK = "slack"
    """
    Messages formatted for consumption by Slack incoming webhooks.
    """
    PULUMI_DEPLOYMENTS = "pulumi_deployments"
    """
    Initiate deployments on a stack from a Pulumi Cloud webhook.
    """
    MICROSOFT_TEAMS = "ms_teams"
    """
    Messages formatted for consumption by Microsoft Teams incoming webhooks.
    """



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['EnvironmentVersionTagArgs', 'EnvironmentVersionTag']

@pulumi.input_type
class EnvironmentVersionTagArgs:
    def __init__(__self__, *,
                 environment: pulumi.Input[str],
                 organization: pulumi.Input[str],
                 revision: pulumi.Input[int],
                 tag_name: pulumi.Input[str]):
        """
        The set of arguments for constructing a EnvironmentVersionTag resource.
        :param pulumi.Input[str] environment: Environment name.
        :param pulumi.Input[str] organization: Organization name.
        :param pulumi.Input[int] revision: Revision number.
        :param pulumi.Input[str] tag_name: Tag name.
        """
        pulumi.set(__self__, "environment", environment)
        pulumi.set(__self__, "organization", organization)
        pulumi.set(__self__, "revision", revision)
        pulumi.set(__self__, "tag_name", tag_name)

    @property
    @pulumi.getter
    def environment(self) -> pulumi.Input[str]:
        """
        Environment name.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: pulumi.Input[str]):
        pulumi.set(self, "environment", value)

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Input[str]:
        """
        Organization name.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def revision(self) -> pulumi.Input[int]:
        """
        Revision number.
        """
        return pulumi.get(self, "revision")

    @revision.setter
    def revision(self, value: pulumi.Input[int]):
        pulumi.set(self, "revision", value)

    @property
    @pulumi.getter(name="tagName")
    def tag_name(self) -> pulumi.Input[str]:
        """
        Tag name.
        """
        return pulumi.get(self, "tag_name")

    @tag_name.setter
    def tag_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "tag_name", value)


class EnvironmentVersionTag(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 environment: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 revision: Optional[pulumi.Input[int]] = None,
                 tag_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        A tag on a specific revision of an environment.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] environment: Environment name.
        :param pulumi.Input[str] organization: Organization name.
        :param pulumi.Input[int] revision: Revision number.
        :param pulumi.Input[str] tag_name: Tag name.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EnvironmentVersionTagArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        A tag on a specific revision of an environment.

        :param str resource_name: The name of the resource.
        :param EnvironmentVersionTagArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EnvironmentVersionTagArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 environment: Optional[pulumi.Input[str]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 revision: Optional[pulumi.Input[int]] = None,
                 tag_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EnvironmentVersionTagArgs.__new__(EnvironmentVersionTagArgs)

            if environment is None and not opts.urn:
                raise TypeError("Missing required property 'environment'")
            __props__.__dict__["environment"] = environment
            if organization is None and not opts.urn:
                raise TypeError("Missing required property 'organization'")
            __props__.__dict__["organization"] = organization
            if revision is None and not opts.urn:
                raise TypeError("Missing required property 'revision'")
            __props__.__dict__["revision"] = revision
            if tag_name is None and not opts.urn:
                raise TypeError("Missing required property 'tag_name'")
            __props__.__dict__["tag_name"] = tag_name
        super(EnvironmentVersionTag, __self__).__init__(
            'pulumiservice:index:EnvironmentVersionTag',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'EnvironmentVersionTag':
        """
        Get an existing EnvironmentVersionTag resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = EnvironmentVersionTagArgs.__new__(EnvironmentVersionTagArgs)

        __props__.__dict__["environment"] = None
        __props__.__dict__["organization"] = None
        __props__.__dict__["revision"] = None
        __props__.__dict__["tag_name"] = None
        return EnvironmentVersionTag(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def environment(self) -> pulumi.Output[str]:
        """
        Environment name.
        """
        return pulumi.get(self, "environment")

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Output[str]:
        """
        Organization name.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter
    def revision(self) -> pulumi.Output[int]:
        """
        Revision number.
        """
        return pulumi.get(self, "revision")

    @property
    @pulumi.getter(name="tagName")
    def tag_name(self) -> pulumi.Output[str]:
        """
        Tag name.
        """
        return pulumi.get(self, "tag_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['TeamArgs', 'Team']

@pulumi.input_type
class TeamArgs:
    def __init__(__self__, *,
                 organization_name: pulumi.Input[str],
                 team_type: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 github_team_id: Optional[pulumi.Input[float]] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Team resource.
        :param pulumi.Input[str] organization_name: The name of the Pulumi organization the team belongs to.
        :param pulumi.Input[str] team_type: The type of team. Must be either `pulumi` or `github`.
        :param pulumi.Input[str] description: Optional. Team description.
        :param pulumi.Input[str] display_name: Optional. Team display name.
        :param pulumi.Input[float] github_team_id: The GitHub ID of the team to mirror. Must be in the same GitHub organization that the Pulumi org is backed by. Required for "github" teams.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] members: List of team members.
        :param pulumi.Input[str] name: The team's name. Required for "pulumi" teams.
        """
        pulumi.set(__self__, "organization_name", organization_name)
        pulumi.set(__self__, "team_type", team_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if github_team_id is not None:
            pulumi.set(__self__, "github_team_id", github_team_id)
        if members is not None:
            pulumi.set(__self__, "members", members)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="organizationName")
    def organization_name(self) -> pulumi.Input[str]:
        """
        The name of the Pulumi organization the team belongs to.
        """
        return pulumi.get(self, "organization_name")

    @organization_name.setter
    def organization_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization_name", value)

    @property
    @pulumi.getter(name="teamType")
    def team_type(self) -> pulumi.Input[str]:
        """
        The type of team. Must be either `pulumi` or `github`.
        """
        return pulumi.get(self, "team_type")

    @team_type.setter
    def team_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "team_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Optional. Team description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        Optional. Team display name.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="githubTeamId")
    def github_team_id(self) -> Optional[pulumi.Input[float]]:
        """
        The GitHub ID of the team to mirror. Must be in the same GitHub organization that the Pulumi org is backed by. Required for "github" teams.
        """
        return pulumi.get(self, "github_team_id")

    @github_team_id.setter
    def github_team_id(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "github_team_id", value)

    @property
    @pulumi.getter
    def members(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of team members.
        """
        return pulumi.get(self, "members")

    @members.setter
    def members(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "members", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The team's name. Required for "pulumi" teams.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class Team(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 github_team_id: Optional[pulumi.Input[float]] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization_name: Optional[pulumi.Input[str]] = None,
                 team_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The Pulumi Cloud offers role-based access control (RBAC) using teams. Teams allow organization admins to assign a set of stack permissions to a group of users.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Optional. Team description.
        :param pulumi.Input[str] display_name: Optional. Team display name.
        :param pulumi.Input[float] github_team_id: The GitHub ID of the team to mirror. Must be in the same GitHub organization that the Pulumi org is backed by. Required for "github" teams.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] members: List of team members.
        :param pulumi.Input[str] name: The team's name. Required for "pulumi" teams.
        :param pulumi.Input[str] organization_name: The name of the Pulumi organization the team belongs to.
        :param pulumi.Input[str] team_type: The type of team. Must be either `pulumi` or `github`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TeamArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The Pulumi Cloud offers role-based access control (RBAC) using teams. Teams allow organization admins to assign a set of stack permissions to a group of users.

        :param str resource_name: The name of the resource.
        :param TeamArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TeamArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 github_team_id: Optional[pulumi.Input[float]] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization_name: Optional[pulumi.Input[str]] = None,
                 team_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TeamArgs.__new__(TeamArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["github_team_id"] = github_team_id
            __props__.__dict__["members"] = members
            __props__.__dict__["name"] = name
            if organization_name is None and not opts.urn:
                raise TypeError("Missing required property 'organization_name'")
            __props__.__dict__["organization_name"] = organization_name
            if team_type is None and not opts.urn:
                raise TypeError("Missing required property 'team_type'")
            __props__.__dict__["team_type"] = team_type
        super(Team, __self__).__init__(
            'pulumiservice:index:Team',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'Team':
        """
        Get an existing Team resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = TeamArgs.__new__(TeamArgs)

        __props__.__dict__["description"] = None
        __props__.__dict__["display_name"] = None
        __props__.__dict__["github_team_id"] = None
        __props__.__dict__["members"] = None
        __props__.__dict__["name"] = None
        __props__.__dict__["organization_name"] = None
        __props__.__dict__["team_type"] = None
        return Team(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Optional. Team description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[Optional[str]]:
        """
        Optional. Team display name.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="githubTeamId")
    def github_team_id(self) -> pulumi.Output[Optional[float]]:
        """
        The GitHub ID of the team to mirror. Must be in the same GitHub organization that the Pulumi org is backed by. Required for "github" teams.
        """
        return pulumi.get(self, "github_team_id")

    @property
    @pulumi.getter
    def members(self) -> pulumi.Output[Sequence[str]]:
        """
        List of team members.
        """
        return pulumi.get(self, "members")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[Optional[str]]:
        """
        The team's name. Required for "pulumi" teams.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationName")
    def organization_name(self) -> pulumi.Output[str]:
        """
        The name of the Pulumi organization the team belongs to.
        """
        return pulumi.get(self, "organization_name")

    @property
    @pulumi.getter(name="teamType")
    def team_type(self) -> pulumi.Output[str]:
        """
        The type of team. Must be either `pulumi` or `github`.
        """
        return pulumi.get(self, "team_type")

